@@ -2,6 +2,7 @@ from reprit.base import generate_repr
 
 from ground.core.hints import QuaternaryPointFunction
 from ground.hints import Coordinate
+from .exact import point_point_point as exact_point_point_point
 from .plain import point_point_point as plain_point_point_point
 from .robust import point_point_point as robust_point_point_point
 
@@ -22,5 +23,6 @@ class Context:
         return self._point_point_point_test
 
 
+exact_context = Context(point_point_point_test=exact_point_point_point.test)
 plain_context = Context(point_point_point_test=plain_point_point_point.test)
 robust_context = Context(point_point_point_test=robust_point_point_point.test)
